#!/bin/bash
# Configure iptables firewall

# Limit PATH
PATH="/sbin:/usr/sbin:/bin:/usr/bin"

# Download
ip_update() {
	wget -q 'https://www.cloudflare.com/ips-v4' -O /etc/iptables/list/CF.list
	wget -q 'http://ipdeny.com/ipblocks/data/countries/ru.zone' -O /etc/iptables/zone/ru.zone
	wget -q 'http://ipdeny.com/ipblocks/data/countries/cn.zone' -O /etc/iptables/zone/cn.zone
	wget -q 'http://ipdeny.com/ipblocks/data/countries/in.zone' -O /etc/iptables/zone/in.zone
	wget -q 'http://ipdeny.com/ipblocks/data/countries/iq.zone' -O /etc/iptables/zone/iq.zone
	wget -q 'http://ipdeny.com/ipblocks/data/countries/jp.zone' -O /etc/iptables/zone/jp.zone
	wget -q 'http://ipdeny.com/ipblocks/data/countries/kp.zone' -O /etc/iptables/zone/kp.zone
	wget -q 'http://ipdeny.com/ipblocks/data/countries/kr.zone' -O /etc/iptables/zone/kr.zone
	wget -q 'http://ipdeny.com/ipblocks/data/countries/id.zone' -O /etc/iptables/zone/id.zone
	wget -q 'http://ipdeny.com/ipblocks/data/countries/cf.zone' -O /etc/iptables/zone/cf.zone
	wget -q 'http://ipdeny.com/ipblocks/data/countries/za.zone' -O /etc/iptables/zone/za.zone
	wget -q 'http://ipdeny.com/ipblocks/data/countries/co.zone' -O /etc/iptables/zone/co.zone
}
# ipset update
firewall_update() {
	ip_update
	for i in $(cat /etc/iptables/zone/*.zone ); do ipset -exist -A drop $i; done
}

# iptables configuration
firewall_start() {
	ipset create drop hash:net family inet hashsize 16384 maxelem 65536
	ip_update
	for i in $(cat /etc/iptables/zone/*.zone ); do ipset -exist -A drop $i; done
	iptables -A INPUT -m set --match-set drop src -j DROP
	iptables -A OUTPUT -m set --match-set drop dst -j DROP
}

# clear iptables configuration
firewall_stop() {
	iptables -F
	iptables -X
	iptables -P INPUT   ACCEPT
	iptables -P FORWARD ACCEPT
	iptables -P OUTPUT  ACCEPT
	ipset destroy drop
}

# execute action
case "$1" in
	start|restart)
		echo "Starting firewall"
		firewall_stop
		firewall_start
		echo "Firewall started"
	;;
	stop)
		echo "Stopping firewall"
		firewall_stop
		echo "Firewall stopped"
	;;
	update)
		echo "Update ipset IPs"
		firewall_update
		echo "updated ipset IPs"
	;;
esac
